@@ -20,6 +20,8 @@
  * (C) Copyright 2008 - 2009 Red Hat, Inc.
  */
 
+#include <config.h>
+
 #include <net/ethernet.h>
 #include <netinet/ether.h>
 #include <string.h>
@@ -29,17 +31,11 @@
 
 #include <nm-setting-connection.h>
 #include <nm-utils.h>
+#include <nm-settings-connection-interface.h>
 
 #include "ce-page.h"
 #include "nma-marshal.h"
 #include "utils.h"
-#include "polkit-helpers.h"
-
-#define DBUS_TYPE_G_ARRAY_OF_STRING         (dbus_g_type_get_collection ("GPtrArray", G_TYPE_STRING))
-#define DBUS_TYPE_G_MAP_OF_VARIANT          (dbus_g_type_get_map ("GHashTable", G_TYPE_STRING, G_TYPE_VALUE))
-#define DBUS_TYPE_G_MAP_OF_MAP_OF_VARIANT   (dbus_g_type_get_map ("GHashTable", G_TYPE_STRING, DBUS_TYPE_G_MAP_OF_VARIANT))
-
-static gboolean internal_request_secrets (CEPage *self, GError **error);
 
 G_DEFINE_ABSTRACT_TYPE (CEPage, ce_page, G_TYPE_OBJECT)
 
@@ -179,148 +175,54 @@ emit_initialized (CEPage *self, GError *error)
 	g_signal_emit (self, signals[INITIALIZED], 0, NULL, error);
 }
 
-static void
-try_secrets_again (PolKitAction *action,
-                   gboolean gained_privilege,
-                   GError *error,
-                   gpointer user_data)
+void
+ce_page_complete_init (CEPage *self,
+                       const char *setting_name,
+                       GHashTable *secrets,
+                       GError *error)
 {
-	CEPage *self = user_data;
-	GError *real_error = NULL;
+	GError *update_error = NULL;
+	GHashTable *setting_hash;
+
+	g_return_if_fail (self != NULL);
+	g_return_if_fail (CE_IS_PAGE (self));
 
 	if (error) {
 		emit_initialized (self, error);
 		return;
-	}
-
-	if (gained_privilege) {
-		/* Yay! Got privilege, try again */
-		internal_request_secrets (self, &real_error);
-	} else if (!error) {
-		/* Sometimes PK screws up and won't return an error even if
-		 * the operation failed.
-		 */
-		g_set_error (&real_error, 0, 0, "%s",
-		             _("Insufficient privileges or unknown error retrieving system connection secrets."));
-	}
-
-	if (real_error)
-		emit_initialized (self, real_error);
-	g_clear_error (&real_error);
-}
-
-static void
-get_secrets_cb (DBusGProxy *proxy, DBusGProxyCall *call, gpointer user_data)
-{
-	CEPage *self = user_data;
-	GError *pk_error = NULL;
-	GError *error = NULL;
-	GHashTable *settings = NULL, *setting_hash;
-	gboolean do_signal = TRUE;
-
-	if (!dbus_g_proxy_end_call (proxy, call, &pk_error,
-	                            DBUS_TYPE_G_MAP_OF_MAP_OF_VARIANT, &settings,
-	                            G_TYPE_INVALID)) {
-		if (pk_helper_is_permission_denied_error (pk_error)) {
-			/* If permission was denied, try to authenticate */
-			if (pk_helper_obtain_auth (pk_error, self->parent_window, try_secrets_again, self, &error))
-				do_signal = FALSE; /* 'secrets' signal will happen after auth result */
-		}
-	} else {
-		/* Update the connection with the new secrets */
-		setting_hash = g_hash_table_lookup (settings, self->setting_name);
-		if (setting_hash) {
-			if (!nm_connection_update_secrets (self->connection,
-			                                   self->setting_name,
-			                                   setting_hash,
-			                                   &error)) {
-				if (!error) {
-					g_set_error (&error, 0, 0, "%s",
-					             _("Failed to update connection secrets due to an unknown error."));
-				}
-			}
-		}
-		g_hash_table_destroy (settings);
-	}
-
-	if (do_signal)
-		emit_initialized (self, error);
-	g_clear_error (&error);
-}
-
-static gboolean
-internal_request_secrets (CEPage *self, GError **error)
-{
-	DBusGProxyCall *call;
-	GPtrArray *hints = NULL;
-
-	g_return_val_if_fail (self != NULL, FALSE);
-	g_return_val_if_fail (self->proxy != NULL, FALSE);
-	g_return_val_if_fail (self->setting_name != NULL, FALSE);
-
-	hints = g_ptr_array_new ();
-	call = dbus_g_proxy_begin_call_with_timeout (self->proxy, "GetSecrets",
-	                                             get_secrets_cb, self, NULL,
-	                                             10000,
-	                                             G_TYPE_STRING, self->setting_name,
-	                                             DBUS_TYPE_G_ARRAY_OF_STRING, hints,
-	                                             G_TYPE_BOOLEAN, FALSE,
-	                                             G_TYPE_INVALID);
-	g_ptr_array_free (hints, TRUE);
-
-	if (!call) {
-		g_set_error (error, 0, 0, "%s", _("Could not request secrets from the system settings service."));
-		return FALSE;
-	}
-
-	return TRUE;
-}
-
-gboolean
-ce_page_initialize (CEPage *self,
-                    const char *setting_name,
-                    GError **error)
-{
-	DBusGConnection *g_connection;
-	gboolean success = FALSE;
-	NMConnectionScope scope;
-
-	g_return_val_if_fail (self != NULL, FALSE);
-	g_return_val_if_fail (self->connection != NULL, FALSE);
-
-	/* Don't need to request secrets from user connections or from
-	 * settings which are known to not require secrets.
-	 */
-	scope = nm_connection_get_scope (self->connection);
-	if (!setting_name || (scope != NM_CONNECTION_SCOPE_SYSTEM)) {
+	} else if (!setting_name || !secrets) {
+		/* Success, no secrets */
 		emit_initialized (self, NULL);
-		return TRUE;
+		return;
 	}
 
-	g_connection = dbus_g_bus_get (DBUS_BUS_SYSTEM, error);
-	if (!g_connection) {
-		g_set_error (error, 0, 0, "%s", _("Could not connect to D-Bus to request connection secrets."));
-		return FALSE;
+	g_assert (setting_name);
+	g_assert (secrets);
+
+	/* Update the connection with the new secrets */
+	setting_hash = g_hash_table_lookup (secrets, setting_name);
+	if (!setting_hash) {
+		/* Success, no secrets */
+		emit_initialized (self, NULL);
+		return;
 	}
 
-	if (self->setting_name)
-		g_free (self->setting_name);
-	self->setting_name = g_strdup (setting_name);
-
-	self->proxy = dbus_g_proxy_new_for_name (g_connection,
-	                                         NM_DBUS_SERVICE_SYSTEM_SETTINGS,
-	                                         nm_connection_get_path (self->connection),
-	                                         NM_DBUS_IFACE_SETTINGS_CONNECTION_SECRETS);
-	if (!self->proxy) {
-		g_set_error (error, 0, 0, "%s", _("Could not create D-Bus proxy for connection secrets."));
-		goto out;
+	if (nm_connection_update_secrets (self->connection,
+	                                  setting_name,
+	                                  setting_hash,
+	                                  &update_error)) {
+		/* Success */
+		emit_initialized (self, NULL);
+		return;
 	}
 
-	success = internal_request_secrets (self, error);
+	if (!update_error) {
+		g_set_error_literal (&update_error, 0, 0,
+		                     _("Failed to update connection secrets due to an unknown error."));
+	}
 
-out:
-	dbus_g_connection_unref (g_connection);
-	return success;
+	emit_initialized (self, update_error);
+	g_clear_error (&update_error);
 }
 
 static void
@@ -359,7 +261,6 @@ finalize (GObject *object)
 	CEPage *self = CE_PAGE (object);
 
 	g_free (self->title);
-	g_free (self->setting_name);
 
 	G_OBJECT_CLASS (ce_page_parent_class)->finalize (object);
 }
